# Example Package
Use funtdsgnr can help you to get yourselfs function and can save in ".py" file.You can use the function at projects too.
And you can export functions at a ".py" file,to test function.